@@ -226,7 +226,7 @@ class anim_text:
                 text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
-                ind = np.where(abs(cur_frame - anim.frames)  == min(abs(cur_frame - anim.frames)))[0][0]
+                ind = int(cur_frame/anim.frames[-1]*len(anim.frames))
                 text.data.body = ('{0:.'+str(fix_place)+'f}').format(data[ind]) + ' ' + label
                     
         else:
@@ -234,7 +234,7 @@ class anim_text:
                 text = ob
                 cur_frame = bpy.context.scene.frame_current
                 
-                ind = np.where(abs(cur_frame - anim.frames)  == min(abs(cur_frame - anim.frames)))[0][0]
+                ind = int(cur_frame/anim.frames[-1]*len(anim.frames))
                 text.data.body = data[ind]
 
         def register():
